Introduction
============

.. include:: includes/all.rst

The ``debops-contrib.homeassistant`` role allows you to setup and manage
`Home Assistant <https://en.wikipedia.org/wiki/Home_Assistant>`_.
Home Assistant is a home automation platform running on Python 3.
It is able to track and control all devices at home and offer a platform for
automating control.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.2.2``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops-contrib.homeassistant

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
